===========================
cryptonium: Crypto library
===========================

.. image:: https://github.com/piper-hq/cryptonium/actions/workflows/build.yml/badge.svg
  :alt: Build
  :target: https://github.com/piper-hq/cryptonium/actions/workflows/build.yml
.. image:: https://img.shields.io/lgtm/alerts/g/piper-hq/cryptonium.svg
  :alt: Total alerts
  :target: https://lgtm.com/projects/g/piper-hq/cryptonium/alerts/
.. image:: https://img.shields.io/github/license/piper-hq/cryptonium
  :alt: License
  :target: https://github.com/piper-hq/cryptonium/blob/main/LICENSE.txt
.. image:: https://img.shields.io/pypi/v/cryptonium
  :alt: PyPI
  :target: https://pypi.org/project/cryptonium
.. image:: https://pepy.tech/badge/cryptonium
  :alt: Downloads
  :target: https://pepy.tech/project/cryptonium
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
  :alt: Code style
  :target: https://github.com/psf/black

``cryptonium`` offers an easy interface to encrypt/decrypt strings and files.

In a nutshell
-------------

Installation
^^^^^^^^^^^^

The easiest way is to use `poetry`_ to manage your dependencies and add *cryptonium* to them.

.. code-block:: toml

    [tool.poetry.dependencies]
    cryptonium = "^0.3.0"

Usage
^^^^^

A class called SymmetricCrypto for encrypting and decrypting strings and files is available.

Links
-----

- `Documentation`_
- `Changelog`_


.. _poetry: https://python-poetry.org/
.. _Changelog: https://github.com/piper-hq/cryptonium/blob/main/CHANGELOG.rst
.. _Documentation: https://cryptonium.readthedocs.io/en/latest/
